@@ -1,6 +1,10 @@
 import os
+
+from seamapi.utils.get_sentry_dsn import get_sentry_dsn
 from .routes import Routes
 import requests
+import sentry_sdk
+import pkg_resources
 from typing import Optional, cast
 from .types import AbstractSeam, SeamAPIException
 
@@ -42,6 +46,7 @@ class Seam(AbstractSeam):
         self,
         api_key: Optional[str] = None,
         api_url: Optional[str] = None,
+        should_report_exceptions: Optional[bool] = False,
     ):
         """
         Parameters
@@ -50,6 +55,8 @@ class Seam(AbstractSeam):
           API key
         api_url : str, optional
           API url
+        should_report_exceptions : bool, optional
+          Defaults to False. If true, thrown exceptions will be reported to Seam.
         """
         Routes.__init__(self)
 
@@ -63,6 +70,17 @@ class Seam(AbstractSeam):
             api_url = os.environ.get("SEAM_API_URL", self.api_url)
         self.api_key = api_key
         self.api_url = cast(str, api_url)
+        self.should_report_exceptions = should_report_exceptions
+
+        if self.should_report_exceptions:
+            self.sentry_client = sentry_sdk.Hub(sentry_sdk.Client(
+                dsn=get_sentry_dsn(),
+            ))
+            self.sentry_client.scope.set_context("sdk_info", {
+                "repository": "https://github.com/seamapi/python",
+                "version": pkg_resources.get_distribution("seamapi").version,
+                "endpoint": self.api_url,
+            })
 
     def make_request(self, method: str, path: str, **kwargs):
         """
@@ -82,9 +100,24 @@ class Seam(AbstractSeam):
         headers = {
             "Authorization": "Bearer " + self.api_key,
             "Content-Type": "application/json",
+            "User-Agent": "Python SDK v" + pkg_resources.get_distribution("seamapi").version + " (https://github.com/seamapi/python)",
         }
         response = requests.request(method, url, headers=headers, **kwargs)
 
+        if self.should_report_exceptions and response.status_code:
+            # Add breadcrumb
+            self.sentry_client.add_breadcrumb(
+                category="http",
+                level="info",
+                data={
+                    "method": method,
+                    "url": url,
+                    "status_code": response.status_code,
+                    "request_id": response.headers.get("seam-request-id", "unknown"),
+                },
+            )
+
+
         parsed_response = response.json()
 
         if response.status_code != 200:
